==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/viking2/dialogs_en.lua <==

dialogId("dr1-m-dlouho", "font_small", "This ship must have sunk long time ago.")

dialogId("dr1-v-urcite", "font_big", "Definitely. It`s one of the earliest drakkars. Judging by the shape of the head, number of spirals and color of the water I think it belonged to the grandfather of Eric the Red.")

dialogId("dr1-v-olaf", "font_big", "Or to the father-in-law of Olaf the Brave.")

dialogId("dr1-v-leif", "font_big", "Or maybe to the great-uncle of Leif the Skillful.")

dialogId("dr1-v-harold", "font_big", "It could also belong to the niece of Harold the Great.")

dialogId("dr1-v-snorr", "font_big", "Or possibly to the aunt of Snorr the Courageous.")

dialogId("dr1-v-thorson", "font_big", "It is even possible it belonged to Thorson the Hard.")

dialogId("dr1-x-erik", "font_lightgrey", "I always thought I was the fishing boat of Eric the Unready... But today I learned the truth. Yes, it`s never too late to start a new life!")

dialogId("dr-m-podivej", "font_small", "Look at that poor dog.")

dialogId("dr-m-nedycha", "font_small", "Doesn't he seem to be breathing kind of strangely?")

dialogId("dr-v-napsa", "font_big", "For a dog under water I think he's doing rather well.")

dialogId("dr-v-nato", "font_big", "He doesn't look all that bad considering that he's been here for a few centuries.")

dialogId("dr-8-ztichni1", "font_viking8", "Shut up!")

dialogId("dr-8-ztichni2", "font_viking8", "Will you shut up already!")

dialogId("dr-8-nenechas", "font_viking8", "So, you`re not going to shut up, are you?")

dialogId("dr-8-aaa", "font_viking8", "Aaaaargh...")

dialogId("dr-6-checheche", "font_viking6", "He-he-he-he-he... Eh-eh-eh-eh...")

dialogId("dr-5-srab1", "font_viking5", "Is it over?")

dialogId("dr-5-srab2", "font_viking5", "Are we safe now?")

dialogId("dr-5-srab3", "font_viking5", "Is the fight over?")

dialogId("dr-5-srab4", "font_viking5", "Is the enemy finally gone?")

dialogId("dr-5-srab5", "font_viking5", "Are we still fighting?")

dialogId("dr-2-uzbudeme1", "font_viking2", "Are we in Valhalla yet, chief?")

dialogId("dr-2-uzbudeme2", "font_viking2", "When are we going to get to Valhalla?")

dialogId("dr-1-aztambudem", "font_viking1", "I`ll let you know once we get there.")

dialogId("dr-2-odskocit", "font_viking2", "Can I go relieve myself, sir?")

dialogId("dr-1-pockej", "font_viking1", "Wait till we get to Valhalla.")

dialogId("dr-2-netrva", "font_viking2", "Isn`t this journey to Valhalla taking a bit too long?")

dialogId("dr-1-trpelivost", "font_viking1", "Patience is the sign of a true warrior.")

dialogId("dr-2-urcite", "font_viking2", "Are you sure this is how to get to Valhalla?")

dialogId("dr-1-bojovnik", "font_viking1", "A warrior has to trust his commander!")

dialogId("dr-1-achjo", "font_viking1", "Ahhh, I`m in charge of a ship full of cowards.")

dialogId("dr-1-procja", "font_viking1", "Why did I have to get a ship full of laughing buffoons?")

dialogId("dr-1-chechtajici", "font_viking1", "Laughing buffoons, a slobbering dog. I think I`ll go drown myself.")

dialogId("dr-3-spravny", "font_viking3", "Real Vikings have beards.")

dialogId("dr-4-copy", "font_viking4", "B-b-braids are in n-nowadays.")

dialogId("dr-3-cojeto", "font_viking3", "What kind of fad is that? Braids? For crying out loud.")

dialogId("dr-4-magazin", "font_viking4", "V-v-viking Fashion M-m-monthly r-recommends a blonde braid to complement a d-d-dark helmet and b-blue shield.")

dialogId("dr-3-stakovou", "font_viking3", "I simply don`t agree with such a fad.")

dialogId("dr-3-radeji", "font_viking3", "You should stick to the Viking traditions instead.")

dialogId("dr-4-moderni", "font_viking4", "B-b-but I`m c-c-cool!")

dialogId("dr-4-erik", "font_viking4", "Even Erik the G-g-great Eric had a b-b-braid!")

dialogId("dr-3-nesmysl", "font_viking3", "Nonsense. He had a beard.")

dialogId("dr-4-taky", "font_viking4", "But h-he also h-had a b-b-braid.")

dialogId("dr-3-nemel", "font_viking3", "He did not. And that`s final.")

dialogId("dr-4-myslis", "font_viking4", "D-d-do you think that a b-b-beard would suit me b-b-better?")

dialogId("dr-3-samozrejme", "font_viking3", "Definitely.")

dialogId("dr-4-budu", "font_viking4", "I`ll th-th-think it o-over.")

dialogId("dr-4-hmmm", "font_viking4", "Hmmm... Ehmmm... Hahmmm...")

dialogId("dr-4-ne", "font_viking4", "N-no, b-b-braids are d-definitely b-b-better.")

dialogId("dr-3-mladez", "font_viking3", "Today`s youth - absolutely unbelievable.")

dialogId("dr-3-chlap", "font_viking3", "A warrior with braids. It`s unheard of.")

dialogId("dr-3-mladi", "font_viking3", "You youngsters just think you can get away with anything today.")

dialogId("dr-4-stejne", "font_viking4", "Well, I still look cool.")

dialogId("dr-7-sm1", "", "")

dialogId("dr-7-sm2", "", "")

dialogId("dr-7-sm3", "", "")

dialogId("dr-7-sm4", "", "")

dialogId("dr-7-sm5", "", "")

dialogId("dr-7-sm6", "", "")

dialogId("dr-7-sm7", "", "")

dialogId("dr-7-sm8", "", "")

dialogId("dr-7-brble1", "", "")

dialogId("dr-7-brble2", "", "")

dialogId("dr-7-brble3", "", "")

dialogId("dr-7-brble4", "", "")

dialogId("dr-7-brble5", "", "")

dialogId("dr-x-buch", "", "")

dialogId("dr-x-pes", "", "")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/viking2/dialogs_en.lua <==

dialogId("dr1-m-dlouho", "font_small", "This ship must have sunk long time ago.")

dialogId("dr1-v-urcite", "font_big", "Definitely. It’s one of the earliest drakkars. Judging by the shape of the head, number of spirals and color of the water I think it belonged to the grandfather of Eric the Red.")

dialogId("dr1-v-olaf", "font_big", "Or to the father-in-law of Olaf the Brave.")

dialogId("dr1-v-leif", "font_big", "Or maybe to the great-uncle of Leif the Skillful.")

dialogId("dr1-v-harold", "font_big", "It could also belong to the niece of Harold the Great.")

dialogId("dr1-v-snorr", "font_big", "Or possibly to the aunt of Snorr the Courageous.")

dialogId("dr1-v-thorson", "font_big", "It is even possible it belonged to Thorson the Hard.")

dialogId("dr1-x-erik", "font_lightgrey", "I always thought I was the fishing boat of Eric the Unready... But today I learned the truth. Yes, it’s never too late to start a new life!")

dialogId("dr-m-podivej", "font_small", "Look at that poor dog.")

dialogId("dr-m-nedycha", "font_small", "Doesn't he seem to be breathing kind of strangely?")

dialogId("dr-v-napsa", "font_big", "For a dog under water I think he's doing rather well.")

dialogId("dr-v-nato", "font_big", "He doesn't look all that bad considering that he's been here for a few centuries.")

dialogId("dr-8-ztichni1", "font_viking8", "Shut up!")

dialogId("dr-8-ztichni2", "font_viking8", "Will you shut up already!")

dialogId("dr-8-nenechas", "font_viking8", "So, you’re not going to shut up, are you?")

dialogId("dr-8-aaa", "font_viking8", "Aaaaargh...")

dialogId("dr-6-checheche", "font_viking6", "He-he-he-he-he... Eh-eh-eh-eh...")

dialogId("dr-5-srab1", "font_viking5", "Is it over?")

dialogId("dr-5-srab2", "font_viking5", "Are we safe now?")

dialogId("dr-5-srab3", "font_viking5", "Is the fight over?")

dialogId("dr-5-srab4", "font_viking5", "Is the enemy finally gone?")

dialogId("dr-5-srab5", "font_viking5", "Are we still fighting?")

dialogId("dr-2-uzbudeme1", "font_viking2", "Are we in Valhalla yet, chief?")

dialogId("dr-2-uzbudeme2", "font_viking2", "When are we going to get to Valhalla?")

dialogId("dr-1-aztambudem", "font_viking1", "I’ll let you know once we get there.")

dialogId("dr-2-odskocit", "font_viking2", "Can I go relieve myself, sir?")

dialogId("dr-1-pockej", "font_viking1", "Wait till we get to Valhalla.")

dialogId("dr-2-netrva", "font_viking2", "Isn’t this journey to Valhalla taking a bit too long?")

dialogId("dr-1-trpelivost", "font_viking1", "Patience is the sign of a true warrior.")

dialogId("dr-2-urcite", "font_viking2", "Are you sure this is how to get to Valhalla?")

dialogId("dr-1-bojovnik", "font_viking1", "A warrior has to trust his commander!")

dialogId("dr-1-achjo", "font_viking1", "Ahhh, I’m in charge of a ship full of cowards.")

dialogId("dr-1-procja", "font_viking1", "Why did I have to get a ship full of laughing buffoons?")

dialogId("dr-1-chechtajici", "font_viking1", "Laughing buffoons, a slobbering dog. I think I’ll go drown myself.")

dialogId("dr-3-spravny", "font_viking3", "Real Vikings have beards.")

dialogId("dr-4-copy", "font_viking4", "B-b-braids are in n-nowadays.")

dialogId("dr-3-cojeto", "font_viking3", "What kind of fad is that? Braids? For crying out loud.")

dialogId("dr-4-magazin", "font_viking4", "V-v-viking Fashion M-m-monthly r-recommends a blonde braid to complement a d-d-dark helmet and b-blue shield.")

dialogId("dr-3-stakovou", "font_viking3", "I simply don’t agree with such a fad.")

dialogId("dr-3-radeji", "font_viking3", "You should stick to the Viking traditions instead.")

dialogId("dr-4-moderni", "font_viking4", "B-b-but I’m c-c-cool!")

dialogId("dr-4-erik", "font_viking4", "Even Erik the G-g-great Eric had a b-b-braid!")

dialogId("dr-3-nesmysl", "font_viking3", "Nonsense. He had a beard.")

dialogId("dr-4-taky", "font_viking4", "But h-he also h-had a b-b-braid.")

dialogId("dr-3-nemel", "font_viking3", "He did not. And that’s final.")

dialogId("dr-4-myslis", "font_viking4", "D-d-do you think that a b-b-beard would suit me b-b-better?")

dialogId("dr-3-samozrejme", "font_viking3", "Definitely.")

dialogId("dr-4-budu", "font_viking4", "I’ll th-th-think it o-over.")

dialogId("dr-4-hmmm", "font_viking4", "Hmmm... Ehmmm... Hahmmm...")

dialogId("dr-4-ne", "font_viking4", "N-no, b-b-braids are d-definitely b-b-better.")

dialogId("dr-3-mladez", "font_viking3", "Today’s youth - absolutely unbelievable.")

dialogId("dr-3-chlap", "font_viking3", "A warrior with braids. It’s unheard of.")

dialogId("dr-3-mladi", "font_viking3", "You youngsters just think you can get away with anything today.")

dialogId("dr-4-stejne", "font_viking4", "Well, I still look cool.")

dialogId("dr-7-sm1", "", "")

dialogId("dr-7-sm2", "", "")

dialogId("dr-7-sm3", "", "")

dialogId("dr-7-sm4", "", "")

dialogId("dr-7-sm5", "", "")

dialogId("dr-7-sm6", "", "")

dialogId("dr-7-sm7", "", "")

dialogId("dr-7-sm8", "", "")

dialogId("dr-7-brble1", "", "")

dialogId("dr-7-brble2", "", "")

dialogId("dr-7-brble3", "", "")

dialogId("dr-7-brble4", "", "")

dialogId("dr-7-brble5", "", "")

dialogId("dr-x-buch", "", "")

dialogId("dr-x-pes", "", "")
